@@ -23,7 +23,7 @@
 	#pragma import on
 #endif
 
-#define TRACE_THREAD
+#define THREAD_READY_FLAG
 
 PP_Begin_Namespace_PowerPlant
 
@@ -70,6 +70,8 @@ enum {
 const UInt32	thread_DefaultStack	= 0;
 const SInt32		thread_WaitForever	= -1;
 
+const int maxPriority = 6;
+
 
 // ===========================================================================
 //	 Data structures
@@ -265,13 +267,16 @@ public:
 	// priority
 	void				SetPriority(UInt32 p)	{ mPriority = p; }
 	UInt32				GetPriority()		{ return mPriority; }
+#ifdef THREAD_READY_FLAG
 	unsigned char		GetReadyFlag()		{ return mReadyFlag; }
+#endif
 
 	// TickCount on thread switch
 	UInt32				mTick;
 	static UInt32		CurrentThreadTicks() { return TickCount() - sThread->mTick; }
 
 	const char *		mName;
+	void *				userData;
 
 protected:
 
@@ -344,8 +349,11 @@ protected:
 	Boolean				mFPU;			// uses FPU ?
 	Boolean				mAsyncCompleted;// true if threads async timer has fired
 	UInt32				mPriority;
+#ifdef THREAD_READY_FLAG
 	unsigned char		mReadyFlag;		// how set to ready? (to avoid unexpected wakeup)
 										// 0:Suspended 1:Resume 2:AsyncResume 3:Wake 4:Unwait
+#endif
+
 #if THREAD_PROFILE
 	ProfilerRefT		mProfilerRef;	// Profiler context
 #endif
@@ -361,8 +369,8 @@ protected:
 
 	static void			EnqueueReadyThread(LThread *);
 	static void			RemoveFromReadyQueue(LThread *);
-	static LThread *		TopOfReadyThread(LThread * caller = NULL);
-	static LThread *		DequeueReadyThread(LThread * caller = NULL);
+	static LThread *		TopOfReadyThread();
+	static LThread *		DequeueReadyThread();
 
 private:
 
@@ -386,6 +394,8 @@ private:
 #if THREAD_DEBUG
 	static pascal void	DoExit(ThreadIDT inThread, void* arg);
 #endif
+	static pascal ThreadID	DoThreadSchedule(SchedulerInfoRecPtr schedulerInfo);
+	
 
 	// static member variables
 	static LThread::Init	sThreadInit;		// class initialisation object
