@@ -37,11 +37,13 @@
 #include	<sys/socket.h>
 #include	<netinet/in.h>
 
+/*
 #if !defined(_SOCKLEN_T) && !defined(__APPLE__)
 #ifndef __socklen_t_defined
 typedef size_t socklen_t;
 #endif
 #endif
+*/
 
 extern SEM stream_lock;
 int max_fid = 3;
@@ -287,12 +289,12 @@ s_get_socketip_file(STREAM * s)
 {
 int ret;
 int er;
-socklen_t size;
+int size;
 struct sockaddr_in ss;
 	if ( s->h.tbl != &s_file_table )
 		return 0;
 	size = sizeof(ss);
-	er = getpeername(s->file.fid,(struct sockaddr*)&ss,&size);
+	er = getpeername(s->file.fid,(struct sockaddr*)&ss,(void*)&size);
 	if ( er < 0 )
 		return 0;
 	ret = ntohl(ss.sin_addr.s_addr);
