@@ -375,8 +375,10 @@ int * d;
 pthread_attr_t tattr;
 struct sched_param param;
 int policy;
+
+
 	f = (void *(*)())func;
-	d = d_alloc(sizeof(int),140);
+	d = d_alloc(sizeof(int));
 	*d = data;
 
 	ret = pthread_attr_init(&tattr);
