@@ -100,7 +100,7 @@ extern void _s_open(STREAM * s,int mode);
 		exit(1);
 	}
 	*open_port = p;
-	ret = d_alloc(sizeof(S_ACCEPT),340);
+	ret = d_alloc(sizeof(S_ACCEPT));
 	ret->h.tbl = &s_accept_table;
 	ret->accept.fid = sd;
 	lock_task(stream_lock);
