@@ -66,7 +66,7 @@ mk_path(L_CHAR * path,int last)
 L_CHAR * ptr, * buf;
 L_CHAR ch;
 char * p;
-	buf = ll_copy_str(path,332);
+	buf = ll_copy_str(path);
 	if ( buf[0] == '/' )
 		ptr = &buf[1];
 	else	ptr = buf;
@@ -97,7 +97,7 @@ ss_printf("set_rcache_dir(1)\n");
 	if ( main_path ) {
 		m_len = l_strlen(main_path);
 		c_len = l_strlen(rcache_path);
-		path = d_alloc((m_len + c_len + 3)*sizeof(L_CHAR),22);
+		path = d_alloc((m_len + c_len + 3)*sizeof(L_CHAR));
 		memcpy(path,main_path,m_len * sizeof(L_CHAR));
 		if ( path[m_len-1] == '/' ) {
 			cpp = m_len;
@@ -137,7 +137,7 @@ L_CHAR * _name;
 	_name = l_string(std_cm,name);
 	len = l_strlen(rcache_dir_path);
 	n_len = l_strlen(_name);
-	ret = d_alloc((len + n_len + 1)*sizeof(L_CHAR),33);
+	ret = d_alloc((len + n_len + 1)*sizeof(L_CHAR));
 	memcpy(ret,rcache_dir_path,len * sizeof(L_CHAR));
 	memcpy(&ret[len],_name,(n_len + 1)* sizeof(L_CHAR));
 	return ret;
@@ -173,8 +173,8 @@ retry:
 		lock_task(rcache_lock);
 		goto retry;
 	}
-	b = d_alloc(sizeof(*b),2);
-	b->path = ll_copy_str(path,111);
+	b = d_alloc(sizeof(*b));
+	b->path = ll_copy_str(path);
 	b->lock = lock;
 	b->tid = get_tid();
 	b->err = 0;
