@@ -27,6 +27,7 @@
 #include	"resource.h"
 #include	"stream.h"
 #include	"rs_cache.h"
+#include	"pri_level.h"
 
 #define PURGE_FILE_ID_LIST 	10
 #define RS_MIN_EXPIRE		120
@@ -800,7 +801,7 @@ ACC_PN_RS_CACHE_HEADER * h;
 		return;
 	if ( rs_cache_header == 0 )
 		return;
-	h = d_alloc(sizeof(ACC_PN_RS_CACHE_HEADER),22);
+	h = d_alloc(sizeof(ACC_PN_RS_CACHE_HEADER));
 	*h = *rs_cache_header;
 	change_endian_rs_cache_header(&h->d);
 	write_filespace(rs_p,h);
@@ -825,7 +826,7 @@ int ret;
 	if ( p == 0 )
 		return -1;
 	ret = -1;
-	h = d_alloc(sizeof(*h),1);
+	h = d_alloc(sizeof(*h));
 	h->h.fofs = 0;
 	h->d.h.size = sizeof(h->d);
 	h->d.h.type = PNT_RS_CACHE_HEADER;
@@ -869,7 +870,7 @@ get_filepath_from_file_id(int id,char * prefix)
 char * f_path;
 L_CHAR * ret;
 
-	f_path = d_alloc(100,1);
+	f_path = d_alloc(100);
 	sprintf(f_path,"f%03i/f%03i/f%03i/f%03i%s",
 		(id >> 24)&0x0ff,
 		(id >> 16)&0x0ff,
@@ -918,7 +919,7 @@ FILE_LIST *
 new_file_list(char * name,FILE_LIST * in)
 {
 FILE_LIST * ret;
-	ret = d_alloc(sizeof(*ret),22);
+	ret = d_alloc(sizeof(*ret));
 	ret->next = in;
 	ret->name = copy_str(name);
 	return ret;
@@ -959,7 +960,7 @@ int i;
 	}
 	closedir(dd);
 	unlink(n_string(std_cm,dir));
-	dir_path = ll_copy_str(dir,33);
+	dir_path = ll_copy_str(dir);
 	for ( i = l_strlen(dir)-1 ; i >= 0 && dir_path[i] != '/' ; i -- );
 	if (  i > 0 ) {
 		dir_path[i] = 0;
@@ -984,7 +985,7 @@ char * buf;
 	filepath = get_filepath_from_file_id(file_id,"");
 	if ( filepath == 0 )
 		return;
-	dir_path = ll_copy_str(filepath,11);
+	dir_path = ll_copy_str(filepath);
 	len = l_strlen(dir_path);
 	dir_path[len-5] = 0;
 	file = ln_copy_str(std_cm,&dir_path[len-4]);
@@ -1005,7 +1006,7 @@ char * buf;
 	closedir(dd);
 	len = strlen(n_string(std_cm,dir_path));
 	for ( _f = ff ; _f ; _f = _f->next ) {
-		buf = d_alloc(len + strlen(_f->name) + 10,22);
+		buf = d_alloc(len + strlen(_f->name) + 10);
 		sprintf(buf,"%s/%s",n_string(std_cm,dir_path),_f->name);
 		unlink(buf);
 		d_f_ree(buf);
@@ -1037,7 +1038,7 @@ retry:
 			close_filespace(rs_p);
 			goto remake;
 		}
-		rs_cache_header = d_alloc(sizeof(*rs_cache_header),33);
+		rs_cache_header = d_alloc(sizeof(*rs_cache_header));
 		rs_cache_header->d = *h;
 		rs_cache_header->h.fofs = fofs;
 		d_f_ree(h);
@@ -1104,7 +1105,7 @@ FAVT_NODE * n;
 STRING_INDEX * ix;
 int len;
 	len = l_strlen(url);
-	ix = d_alloc(STRING_IX_LENGTH_1(len),11);
+	ix = d_alloc(STRING_IX_LENGTH_1(len));
 	ix->fofs = 0;
 	l_strcpy(ix->d,url);
 	n = favt_search(r,root_node(r),ix,favt_cmp_string_1);
@@ -1214,7 +1215,7 @@ int inc;
 	_purge_rs_cache_header();
 
 	len = (l_strlen(url)+1)*sizeof(L_CHAR);
-	d = d_alloc(sizeof(ACC_PN_RS_CACHE_DATA) + len,222);
+	d = d_alloc(sizeof(ACC_PN_RS_CACHE_DATA) + len);
 	d->d.file_id = file_id;
 	d->d.expire = expire;
 	d->d.h.type = PNT_RS_CACHE_DATA;
@@ -1231,7 +1232,7 @@ int inc;
 		resource_cache.err = RE_DESTROY;
 		return -1;
 	}
-	ix = d_alloc(STRING_IX_LENGTH_1(slen = l_strlen(url)),22);
+	ix = d_alloc(STRING_IX_LENGTH_1(slen = l_strlen(url)));
 	ix->fofs = data_ofs;
 	l_strcpy(ix->d,url);
 	n = favt_alloc_node(r,ix,STRING_IX_LENGTH_1(slen));
@@ -1284,7 +1285,7 @@ int len;
 		return -1;
 	}
 	len = l_strlen(url);
-	ix = d_alloc(STRING_IX_LENGTH_1(len),22);
+	ix = d_alloc(STRING_IX_LENGTH_1(len));
 	ix->fofs = 0;
 	l_strcpy(ix->d,url);
 	n = favt_delete(r,&r->node,ix,favt_cmp_string_1);
@@ -1360,7 +1361,7 @@ L_CHAR * from;
 	from = ptr;
 	if ( from[0] == LCC_ERROR )
 		return 0;
-	return ll_copy_str(from,11);
+	return ll_copy_str(from);
 }
 
 
@@ -1433,7 +1434,7 @@ BIB_LIST * bl;
 		return -1;
 	data = c->ptr;
 	c = c->next;
-	bl = d_alloc(sizeof(*bl),22);
+	bl = d_alloc(sizeof(*bl));
 	bl->data = string_to_host(data);
 	bl->type = string_to_host(type);
 	bl->qualifier = string_to_host(q);
@@ -1485,11 +1486,11 @@ L_CHAR * f;
 	c = lst->chain_head;
 	if ( c == 0 )
 		goto end1;
-	get_url2(&u_entry,(L_CHAR*)c->ptr,3);
+	get_url2(&u_entry,(L_CHAR*)c->ptr);
 	c = c->next;
 	if ( c == 0 )
 		goto end2;
-	get_url2(&u_target,(L_CHAR*)c->ptr,3);
+	get_url2(&u_target,(L_CHAR*)c->ptr);
 	ret = new_resource_entry(rh->type,&u_entry);
 	set_resource_target(ret,&u_target);
 	ret->h.flags = (~(RF_COMPLETE|RF_FIX))&
@@ -1519,7 +1520,7 @@ L_CHAR * f;
 			goto err;
 	}
 	setup_c_unit(
-		&ret->h.cu,-1,f=ll_copy_str(get_url_str2(&ret->h.entry),123),
+		&ret->h.cu,-1,f=ll_copy_str(get_url_str2(&ret->h.entry)),
 		ret->h.meta,0);
 	d_f_ree(f);
 	goto end3;
@@ -1542,7 +1543,7 @@ set_rs_clip(CLIP ** c_head,RECORD_LIST * lst)
 CLIP * cp;
 PN_RS_CLIP * cpp;
 	cpp = lst->data;
-	cp = d_alloc(sizeof(*cp),3);
+	cp = d_alloc(sizeof(*cp));
 	cp->type = cpp->type;
 	cp->shape = cpp->shape;
 	switch ( cpp->type ) {
@@ -1569,7 +1570,7 @@ RECORD_LIST * lst;
 	mp = lst->data;
 	c = lst->chain_head;
 
-	m = d_alloc(sizeof(*m),22);
+	m = d_alloc(sizeof(*m));
 	m->depth = mp->depth;
 	m->flags = mp->flags;
 	m->mod_time_org = mp->mod_time_org;
@@ -1583,15 +1584,15 @@ RECORD_LIST * lst;
 
 	if ( c == 0 )
 		goto err;
-	get_url2(&m->src_url,c->ptr,2);
+	get_url2(&m->src_url,c->ptr);
 	c = c->next;
 	if ( c == 0 )
 		goto err1;
-	get_url2(&m->dest_url,c->ptr,3);
+	get_url2(&m->dest_url,c->ptr);
 	c = c->next;
 	if ( c == 0 )
 		goto err2;
-	get_url2(&m->map_url,c->ptr,4);
+	get_url2(&m->map_url,c->ptr);
 	c = c->next;
 
 	for ( ; lst ; lst = lst->next ) {
@@ -1649,7 +1650,7 @@ CHAIN_LIST * c;
 	c = c->next;
 	if ( c == 0 )
 		goto err;
-	ret->c.cid = d_alloc(c->len,2);
+	ret->c.cid = d_alloc(c->len);
 	memcpy(ret->c.cid,c->ptr,c->len);
 	c = c->next;
 	if ( c == 0 )
@@ -1752,6 +1753,7 @@ RESOURCE * ret;
 PN_RS_DRAW_GB * g;
 CHAIN_LIST * c;
 int i;
+extern void (*draw_gb_indicate_task)();
 	g = lst->data;
 	ret = resource_rs_res_header(&c,&lst);
 	if ( ret == 0 )
@@ -1762,7 +1764,7 @@ int i;
 	ret->draw_gb.resolution = g->resolution;
 	ret->draw_gb.matrix_ofs = g->matrix_ofs;
 	ret->draw_gb.pitch_list
-		= d_alloc(sizeof(GB_POINT)*g->level,35);
+		= d_alloc(sizeof(GB_POINT)*g->level);
 	for ( i = 0 ; i < g->level ; i ++ )
 		ret->draw_gb.pitch_list[i] = g->pitch_list[i];
 	ret->draw_gb.loop_no = g->loop_no;
@@ -1776,6 +1778,16 @@ int i;
 			goto err;
 	}
 	new_vector_option2(ret,NR_NEW,ret->draw_gb.level);
+	memset(&ret->draw_gb.ir_que,0,sizeof(SYS_QUEUE));
+	if ( draw_gb_indicate_task ) {
+		ret->draw_gb.ir_que.flags = QF_FIFO;
+		ret->draw_gb.ir_que.gc_func = 0;
+		ret->draw_gb.ir_que.gc_get = 0;
+		ret->draw_gb.ir_que.key_func = draw_gb_indicate_task;
+		ret->draw_gb.ir_que.pri = PRI_FETCH_STRONG;
+		ret->draw_gb.ir_que.work = ret;
+		setup_queue(&ret->draw_gb.ir_que);
+	}
 	return ret;
 err:
 	free_resource_entry(ret);
@@ -1791,7 +1803,7 @@ MAP_POINT_LIST * m;
 	mp = lst->data;
 	c = lst->chain_head;
 
-	m = d_alloc(sizeof(*m),22);
+	m = d_alloc(sizeof(*m));
 	m->src = mp->src;
 	m->dest = mp->dest;
 
@@ -1849,7 +1861,7 @@ int i;
 MAP_POINT_LIST * mp;
 	tp = lst->data;
 	c = lst->chain_head;
-	ret = d_alloc(sizeof(*ret),33);
+	ret = d_alloc(sizeof(*ret));
 	for ( i = 0 ; i < 3 ; i ++ )
 		ret->ptp[i] = tp->ptp[i];
 	ret->a = tp->a;
@@ -1896,20 +1908,20 @@ TRIANGLE * t1, * t2;
 		return 0;
 	if ( c == 0 )
 		goto err;
-	get_url2(&ret->map.src,c->ptr,2);
+	get_url2(&ret->map.src,c->ptr);
 	c = c->next;
 	if ( c == 0 )
 		goto err;
-	get_url2(&ret->map.dest,c->ptr,3);
+	get_url2(&ret->map.dest,c->ptr);
 	c = c->next;
 	coordinate_unit_to_host(&ret->map.cu_src,&c);
 	coordinate_unit_to_host(&ret->map.cu_dest,&c);
 /*
-	url = ll_copy_str(get_url_str2(&ret->map.src),22);
+	url = ll_copy_str(get_url_str2(&ret->map.src));
 	setup_c_unit(&ret->map.cu_src,w->ses,url,0,0);
 	d_f_ree(url);
 
-	url = ll_copy_str(get_url_str2(&ret->map.dest),22);
+	url = ll_copy_str(get_url_str2(&ret->map.dest));
 	setup_c_unit(&ret->map.cu_dest,w->ses,url,0,0);
 	d_f_ree(url);
 */
@@ -2018,7 +2030,7 @@ static L_CHAR nl[2] = {LCC_ERROR,0};
 	}
 	else {
 		if ( flag == 1 )
-			str = ll_copy_str(str,11);
+			str = ll_copy_str(str);
 		set_recordlist_chain(tar,str,
 			(l_strlen(str)+1)*sizeof(L_CHAR),
 			flag);
@@ -2666,7 +2678,7 @@ retry:
 			goto idle;
 	}
 
-	url = ll_copy_str(get_url_str2(&b->r->h.entry),22);
+	url = ll_copy_str(get_url_str2(&b->r->h.entry));
 
 	now = get_xltime();
 	if ( b->r->h.modify == 0 )
