@@ -26,9 +26,12 @@
 #include	"resource.h"
 #include	"lock_level.h"
 #include	"task.h"
+#include	"queue.h"
+#include	"pri_level.h"
 
 int default_dgb_pixel = DEFAULT_DGB_PIXEL;
 SEM draw_lock;
+void (*draw_gb_indicate_task)();
 
 void
 init_vector()
@@ -38,39 +41,39 @@ init_vector()
 }
 
 void
-lock_pdb_lock(RESOURCE * r,int msg)
+pdb_err_sensitive(RESOURCE * r,int on_flag)
+{
+	lock_task(draw_lock);
+	r->draw_gb.pdb_err_sensitive = on_flag;
+	wakeup_task((int)&r->draw_gb.pdb_lock);
+	unlock_task(draw_lock,"lock_pdb_lock");
+}
+
+int
+xx_lock_pdb_lock(RESOURCE * r,int err_sensitive,char *file,int line)
 {
 int t;
-/*
-ss_printf("lock_pdb 1 %ls %i\n",
-get_url_str2(&r->h.entry),
-get_tid());
-*/
 	lock_task(draw_lock);
-/*
-printf("lock_pdb 2 %i\n",get_tid());
-*/
 	t = get_tid();
 	if ( r->draw_gb.pdb_lock == 0 )
 		goto next;
 	if ( r->draw_gb.pdb_lock_task == t )
 		goto next;
 	for ( ; r->draw_gb.pdb_lock ; ) {
-/*
-printf("lock_pdb 3 %i\n",get_tid());
-*/
+		if ( err_sensitive && r->draw_gb.pdb_err_sensitive ) {
+			unlock_task(draw_lock,"lock_pdb_lock");
+			return -1;
+		}
 		sleep_task((int)&r->draw_gb.pdb_lock,draw_lock);
-/*
-printf("lock_pdb 4 %i\n",get_tid());
-*/
 		lock_task(draw_lock);
 	}
 next:
-	if ( msg )
-		r->draw_gb.pdb_lock_msg = msg;
+	r->draw_gb.pdb_lock_file = file;
+	r->draw_gb.pdb_lock_line = line;
 	r->draw_gb.pdb_lock ++;
 	r->draw_gb.pdb_lock_task = t;
 	unlock_task(draw_lock,"lock_pdb_lock");
+	return 0;
 }
 
 
@@ -151,7 +154,16 @@ non_prog:
 
 	new_vector_option1(r,ds);
 
-	r->draw_gb.ir_queue = 0;
+	memset(&r->draw_gb.ir_que,0,sizeof(SYS_QUEUE));
+	if ( draw_gb_indicate_task ) {
+		r->draw_gb.ir_que.flags = QF_FIFO;
+		r->draw_gb.ir_que.gc_func = 0;
+		r->draw_gb.ir_que.gc_get = 0;
+		r->draw_gb.ir_que.key_func = draw_gb_indicate_task;
+		r->draw_gb.ir_que.pri = PRI_FETCH_STRONG;
+		r->draw_gb.ir_que.work = r;
+		setup_queue(&r->draw_gb.ir_que);
+	}
 	r->draw_gb.ischeme = 0;
 	r->draw_gb.onmap_indicate_size = DEFAULT_ONMAP_INDICATE_SIZE;
 	return 0;
@@ -213,7 +225,17 @@ pdb_prog:
 	}
 	new_vector_option2(r,ds,level);
 
-	r->draw_gb.ir_queue = 0;
+	memset(&r->draw_gb.ir_que,0,sizeof(SYS_QUEUE));
+	if ( draw_gb_indicate_task ) {
+		r->draw_gb.ir_que.flags = QF_FIFO;
+		r->draw_gb.ir_que.gc_func = 0;
+		r->draw_gb.ir_que.gc_get = 0;
+		r->draw_gb.ir_que.key_func = draw_gb_indicate_task;
+		r->draw_gb.ir_que.pri = PRI_FETCH_STRONG;
+		r->draw_gb.ir_que.work = r;
+		setup_queue(&r->draw_gb.ir_que);
+	}
+
 	r->draw_gb.ischeme = 0;
 	r->draw_gb.onmap_indicate_size = DEFAULT_ONMAP_INDICATE_SIZE;
 	return 0;
