@@ -128,13 +128,13 @@ L_CHAR * url;
 			e_param = "src/dest";
 			goto subtype_error;
 		}
-		map_url = ll_copy_str(get_url_str2(&r->h.entry),123);
+		map_url = ll_copy_str(get_url_str2(&r->h.entry));
 		url = compose_url(map_url,src);
-		get_url2(&r->map.src,url,1610);
+		get_url2(&r->map.src,url);
 		setup_c_unit(&r->map.cu_src,-1,url,0,0);
 		d_f_ree(url);
 		url = compose_url(map_url,dest);
-		get_url2(&r->map.dest,url,1611);
+		get_url2(&r->map.dest,url);
 		setup_c_unit(&r->map.cu_dest,-1,url,0,0);
 		d_f_ree(url);
 
@@ -754,13 +754,13 @@ add_mh(MAP_HISTORY * mh1,MAP_HISTORY * mh2)
 MAP_HISTORY * mh3,* mh4,* ret;
 	mh3 = 0;
 	for ( ; mh1 ; mh1 = mh1->next ) {
-		mh4 = d_alloc(sizeof(*mh4),1660);
+		mh4 = d_alloc(sizeof(*mh4));
 		*mh4 = *mh1;
 		mh4->next = mh3;
 		mh3 = mh4;
 	}
 	for ( ; mh2 ; mh2 = mh2->next ) {
-		mh4 = d_alloc(sizeof(*mh4),53);
+		mh4 = d_alloc(sizeof(*mh4));
 		*mh4 = *mh2;
 		mh4->next = mh3;
 		mh3 = mh4;
@@ -781,7 +781,7 @@ rev_mh(MAP_HISTORY * mh)
 MAP_HISTORY * ret,* m1;
 	ret = 0;
 	for ( ; mh ; mh = mh->next ) {
-		m1 = d_alloc(sizeof(*m1),54);
+		m1 = d_alloc(sizeof(*m1));
 		*m1 = *mh;
 		m1->dir = 1-m1->dir;
 		m1->next = ret;
@@ -796,7 +796,7 @@ copy_mh(MAP_HISTORY * mh)
 MAP_HISTORY * ret1,* ret2, * m1;
 	ret1 = 0;
 	for ( ; mh ; mh = mh->next ) {
-		m1 = d_alloc(sizeof(*m1),55);
+		m1 = d_alloc(sizeof(*m1));
 		*m1 = *mh;
 		m1->next = ret1;
 		ret1 = m1;
@@ -828,7 +828,7 @@ new_mh(RESOURCE * m,short dir)
 MAP_HISTORY * ret;
 if ( m == 0 )
 printf("***** new_mh\n");
-	ret = d_alloc(sizeof(*ret),56);
+	ret = d_alloc(sizeof(*ret));
 	ret->dir = dir;
 	ret->type = MHT_MAP;
 	ret->d.map = m;
