@@ -397,7 +397,7 @@ L_CHAR * f, * g;
 	if ( err < 0 ) {
 		f = get_url_str2(&w->url);
 		if ( f ) {
-			g = ll_copy_str(f,22);
+			g = ll_copy_str(f);
 			purge_rcache(g);
 			d_f_ree(g);
 		}
@@ -434,7 +434,7 @@ L_CHAR * f, * g;
 	if ( err < 0 ) {
 		f = get_url_str2(&w->url);
 		if ( f ) {
-			g = ll_copy_str(f,22);
+			g = ll_copy_str(f);
 			purge_rcache(g);
 			d_f_ree(g);
 		}
@@ -467,7 +467,7 @@ L_CHAR * f,* g;
 	if ( err < 0 ) {
 		f = get_url_str2(&w->url);
 		if ( f ) {
-			g = ll_copy_str(f,22);
+			g = ll_copy_str(f);
 			purge_rcache(g);
 			d_f_ree(g);
 		}
@@ -497,7 +497,7 @@ L_CHAR * buf;
 int len;
 	copy_url(&w->url,&w->result->h.entry);
 	len = l_strlen(w->url.resource);
-	buf = d_alloc(sizeof(L_CHAR)*(len+10),1235);
+	buf = d_alloc(sizeof(L_CHAR)*(len+10));
 	memcpy(buf,w->url.resource,
 		sizeof(L_CHAR)*len);
 	memcpy(&buf[len],l_string(std_cm,".chi"),sizeof(L_CHAR)*5);
@@ -520,7 +520,7 @@ LOAD_RESOURCE_WORK *
 new_lrw(LOAD_RESOURCE_WORK * w)
 {
 LOAD_RESOURCE_WORK * ret;
-	ret = new_queue_node(sizeof(*ret),1234);
+	ret = new_queue_node(sizeof(*ret));
 	ret->req_next = w;
 	ret->que_next  = 0;
 	ret->option = LRO_FULL;
@@ -822,7 +822,7 @@ COORDINATE_UNIT * cup;
 		{}
 	}
 	wp = w;
-	cup = d_alloc(sizeof(*cup),123);
+	cup = d_alloc(sizeof(*cup));
 	for ( ; wp ; wp = wp->que_next ) {
 		if ( wp->err != LRWE_HANDLING )
 			continue;
@@ -858,7 +858,7 @@ COORDINATE_UNIT * cup;
 			wp->rt->resource_type_num,&wp->url);
 		if ( wp->target ) {
 		URL u;
-			get_url2(&u,wp->target,12);
+			get_url2(&u,wp->target);
 			set_resource_target(rr,&u);
 			free_url(&u);
 		}
@@ -950,7 +950,7 @@ ss_printf("\n");
 		if ( wp->err == LRWE_HANDLING ) {
 			if ( wp->rt->loading_function ) {
 				lp = new_lrw(lp);
-				lp->h.key = ll_copy_str(key,33);
+				lp->h.key = ll_copy_str(key);
 				lp->que_next = lp->req_next;
 				lp->err = LRWE_HANDLING;
 				(*wp->rt->loading_function)(lp,wp);
@@ -965,7 +965,7 @@ ss_printf("\n");
 			lpp->wup = (int)lp;
 		_load_meta_list_insert(ses,&res_lp1,"data",0,lp);
 		lp = new_lrw(lp);
-		lp->h.key = ll_copy_str(key,334);
+		lp->h.key = ll_copy_str(key);
 		lp->err = LRWE_HANDLING;
 		insert_queue(&res_q3,lp,1);
 	}
@@ -1072,7 +1072,7 @@ L_CHAR * url;
 int ret;
 RESOURCE * rr;
 RS_BUF rsb;
-	url = ll_copy_str(get_url_str2(u),22);
+	url = ll_copy_str(get_url_str2(u));
 	setup_c_unit(cu,-1,url,0,0);
 
 	if ( cu->system )
@@ -1136,7 +1136,6 @@ XL_SEXP * ret, * last_tag;
 bomb();
 			if ( get_rs_resource_cache(&rsb,
 					get_url_str2(&wp->url)) < 0 ) {
-bomb();
 /*
 ss_printf("GET EMPTY %ls\n",get_url_str2(&wp->url));
 */
@@ -1146,9 +1145,10 @@ ss_printf("GET EMPTY %ls\n",get_url_str2(&wp->url));
 /*
 ss_printf("GET SUCCESS %ls\n",get_url_str2(&wp->url));
 */
-bomb();
 			if ( rsb.flags & RSBF_MAP ) {
+/*
 ss_printf("MAP--------\n");
+*/
 				rs_cache_setup_c_unit(
 					ses,
 					&rsb.r->map.src,
@@ -1518,7 +1518,7 @@ ss_printf("IN (%i) %ls\n",get_tid(),entry);
 			wp->err = LRWE_ERROR_URL;
 			continue;
 		}
-		entry = ll_copy_str(entry,123);
+		entry = ll_copy_str(entry);
 		wp->result = search_resource_by_entry(&wp->url);
 		wp->meta_result = 0;
 		wp->wup = (int)w;
@@ -1718,7 +1718,7 @@ resource_check(L_CHAR * url_str,int option)
 {
 RESOURCE * r;
 URL u;
-	get_url2(&u,url_str,346);
+	get_url2(&u,url_str);
 	r = search_resource_by_entry(&u);
 	free_url(&u);
 	if ( r == 0 ) {
