@@ -169,6 +169,7 @@ new_mp_route_t(L_CHAR * start,L_CHAR * target,int flags)
 {
 MP_ROUTE_T * n;
 	n = new_queue_node(sizeof(*n));
+	memset(n,0,sizeof(*n));
 	n->start = ll_copy_str(start);
 	n->target = ll_copy_str(target);
 	n->flags = flags;
@@ -1382,6 +1383,16 @@ ss_printf("ERR %ls %ls\n",n->handle1_start,n->handle1_target);
 			goto err;
 		}
 ss_printf("ERR RETRY %ls %ls\n",n->handle1_start,n->handle1_target);
+		r = n->route;
+		n->route = 0;
+		if ( r ) {
+			for ( ; r->lwait ; ) {
+				wakeup_task((int)r);
+				sleep_task((int)r,route_lock);
+				lock_task(route_lock);
+			}
+			_delete_route(&direct,r);
+		}
 		n->flags |= RQT_ROUTE_REVERSE;
 		unlock_task(route_lock,"rr_task2");
 
@@ -1845,31 +1856,38 @@ set_cpu_msg(2003);
 			goto nx1;
 		}
 		get_url2(&uu,crd_prev->url);
-		if ( url_cmp(&uu,&r->map.src) == 0 ) {
+		if ( url_cmp_str(&uu,&r->map.src) == 0 ) {
+			free_url(&uu);
 			get_url2(&uu,crd_next->url);
-			if ( url_cmp(&uu,&r->map.dest) ) {
+			if ( url_cmp_str(&uu,&r->map.dest) ) {
+				free_url(&uu);
 				err_flag = 1;
 				insert_purge_url(map->url);
 				goto nx1;
 			}
+			free_url(&uu);
 			ret = cons_mh(r,MHD_REVERSE,ret);
 		}
 		else {
-			if ( url_cmp(&uu,&r->map.dest) ) {
+			if ( url_cmp_str(&uu,&r->map.dest) ) {
+				free_url(&uu);
 				err_flag = 1;
 				insert_purge_url(map->url);
 				goto nx1;
 			}
+			free_url(&uu);
 			get_url2(&uu,crd_next->url);
-			if ( url_cmp(&uu,&r->map.src) ) {
+			if ( url_cmp_str(&uu,&r->map.src) ) {
+				free_url(&uu);
 				err_flag = 1;
 				insert_purge_url(map->url);
 				goto nx1;
 			}
+			free_url(&uu);
 			ret = cons_mh(r,MHD_FORWARD,ret);
 		}
 	nx1:
-		free_url(&uu);
+		{}
 	}
 	if ( err_flag )
 		goto err;
@@ -1879,7 +1897,7 @@ set_cpu_msg(2004);
 set_cpu_msg(2005);
 
 	get_url2(&uu,mpr->head->url);
-	if ( url_cmp(&uu,u) == 0 ) {
+	if ( url_cmp_str(&uu,u) == 0 ) {
 		ret1 = rev_mh(ret);
 		free_mh(ret);
 		ret = ret1;
