@@ -75,7 +75,7 @@ extern XLISP_ENV * gv_resource_env[];
 void
 load_coordinate_option()
 {
-	assert_ls(LSF_ASSERT);
+	assert_ls_all(LSF_ASSERT);
 }
 
 void
@@ -162,9 +162,9 @@ GB_RECT g;
 			if ( l_strcmp(&m->src_url.resource[len-4],
 					l_string(std_cm,".crd")) )
 				continue;
-			if ( url_cmp(&m->map_url,&bw->route[0]) )
+			if ( url_cmp_str(&m->map_url,&bw->route[0]) )
 				continue;
-			if ( url_cmp(&m->src_url,&bw->route[1]) )
+			if ( url_cmp_str(&m->src_url,&bw->route[1]) )
 				continue;
 			*hit_route = 1;
 		}
@@ -187,7 +187,7 @@ GB_RECT g;
 			  = load_resource(bw->ses,&m->map_url,Q_PRI_OBJ);
 			if ( m->map_file == 0 )
 				goto err;
-			if ( url_cmp(&m->map_file->map.dest,
+			if ( url_cmp_str(&m->map_file->map.dest,
 					&r->h.entry) )
 				goto err;
 			ret = 1;
@@ -265,9 +265,10 @@ GB_RECT g;
 	}
 	if ( this_coord ) {
 	WF_ID wfid;
-		wfid = wf_search(r);
+	GBVIEW_FLAME * gf;
+		gf = wf_search(&wfid,r);
 		if ( wfid )
-			win_flame_dirty(wfid,0,
+			win_flame_dirty(gf,wfid,0,
 				WFF_DIRTY,
 				0);
 	}
@@ -361,7 +362,7 @@ LOAD_RESOURCE_WORK * wp;
 
 	ret = 0;
 	wp = w;
-
+	this_coord = 0;
 	for ( m = R_NEXT(MAP*,&r->c.map_children);
 			m != (MAP*)&r->c.map_children;
 			m = R_NEXT(MAP*,&m->h) ) {
@@ -384,12 +385,12 @@ LOAD_RESOURCE_WORK * wp;
 				= get_lrw(w,&m->map_url);
 			if ( m->map_file == 0 )
 				goto err;
-			if ( url_cmp(&m->map_file->map.dest,
+			if ( url_cmp_str(&m->map_file->map.dest,
 					&r->h.entry) ) {
 				m->map_file = 0;
 				goto err;
 			}
-			if ( url_cmp(&m->map_file->map.src,
+			if ( url_cmp_str(&m->map_file->map.src,
 					&m->src_url) ) {
 				m->map_file = 0;
 				goto err;
@@ -449,9 +450,10 @@ LOAD_RESOURCE_WORK * wp;
 	}
 	if ( this_coord ) {
 	WF_ID wfid;
-		wfid = wf_search(r);
+	GBVIEW_FLAME * gf;
+		gf = wf_search(&wfid,r);
 		if ( wfid )
-			win_flame_dirty(wfid,0,
+			win_flame_dirty(gf,wfid,0,
 				WFF_DIRTY,
 				0);
 	}
@@ -564,9 +566,10 @@ GB_RECT g;
 	}
 	if ( this_coord ) {
 	WF_ID wfid;
-		wfid = wf_search(r);
+	GBVIEW_FLAME * gf;
+		gf = wf_search(&wfid,r);
 		if ( wfid ) {
-			win_flame_dirty(wfid,0,
+			win_flame_dirty(gf,wfid,0,
 				WFF_DIRTY,
 				0);
 		}
@@ -594,9 +597,9 @@ MAP_HISTORY * mh;
 			if ( l_strcmp(&m->dest_url.resource[len-4],
 					l_string(std_cm,".crd")) )
 				continue;
-			if ( url_cmp(&m->map_url,&bw->route[0]) )
+			if ( url_cmp_str(&m->map_url,&bw->route[0]) )
 				continue;
-			if ( url_cmp(&m->dest_url,&bw->route[1]) )
+			if ( url_cmp_str(&m->dest_url,&bw->route[1]) )
 				continue;
 			*hit_route = 1;
 		}
@@ -883,6 +886,7 @@ int ret;
 
 void
 draw_coordinate(
+	GBVIEW_FLAME * gf,
 	RESOURCE * r,
 	DRAW_WORK * dw)
 {
@@ -941,7 +945,8 @@ int reso_cnt,minus_cnt,rect_cnt;
 			}
 			continue;
 		}
-		m1->src->draw_gb.hit_outofcircle = 0;
+		if ( m1->src->h.type == RT_DRAW_GB )
+			m1->src->draw_gb.hit_outofcircle = 0;
 		dw1.limit_reso = -1;
 		switch ( m1->src->h.type ) {
 		case RT_DRAW_GB:
@@ -965,6 +970,7 @@ int reso_cnt,minus_cnt,rect_cnt;
 
 			unlock_task(res_lock,"draw_coordinate");
 			draw_resource(
+				gf,
 				m1->src,
 				&dw1);
 			lock_task(res_lock);
@@ -1022,6 +1028,7 @@ rect_cnt ++;
 				dw1.surp.ptr,dw1.surp.reso,SURP_NOS);
 			unlock_task(res_lock,"draw_coordinate");
 			draw_resource(
+				gf,
 				m1->src,
 				&dw1);
 			lock_task(res_lock);
@@ -1130,6 +1137,7 @@ MAP * m1;
 
 void
 get_point_coordinate(
+	GBVIEW_FLAME * gf,
 	RESOURCE* r,
 	GET_POINT_WORK * w)
 {
@@ -1141,7 +1149,7 @@ GB_POINT pp,p;
 GET_POINT_WORK ww;
 
 	p = w->pt;
-	in = _search_indicate(&r->h.entry);
+	in = _search_indicate(gf,&r->h.entry);
 	if ( in && (in->flags&IF_COORDINATE) ) {
 		in->status = IS_COORDINATE;
 		in->result = p;
@@ -1167,6 +1175,7 @@ GET_POINT_WORK ww;
 		ww.pt = pp;
 		unlock_task(res_lock,"point");
 		if ( get_point_resource(
+				gf,
 				m1->src,&ww) == 0 ) {
 			if ( in && in->flags&IF_OBJECT ) {
 				in->status |= IS_OBJECT;
@@ -1177,3 +1186,30 @@ GET_POINT_WORK ww;
 	}
 	unlock_task(res_lock,"point");
 }
+
+int
+exit_lock_coord(
+	RESOURCE * r,
+	int data)
+{
+MAP * m1;
+
+	lock_task(res_lock);
+
+	for ( m1 = R_NEXT(MAP*,&r->c.map_children) ; 
+			m1 != (MAP*)&r->c.map_children ;
+			m1 = R_NEXT(MAP*,&m1->h) ) {
+		if ( m1->flags & MF_BROWSE )
+			continue;
+		if ( m1->src == 0 )
+			continue;
+		if ( m1->map_file == 0 )
+			continue;
+		unlock_task(res_lock,"check_coordinate");
+		exit_lock_resource(m1->src,data);
+		exit_lock_resource(m1->map_file,data);
+		lock_task(res_lock);
+	}
+	unlock_task(res_lock,"check_coordinate");
+	return 0;
+}
