@@ -183,7 +183,7 @@ XL_SEXP * x, * y;
 		return ret;
 	if ( r->h.type != RT_DRAW_GB )
 		er_panic("dgb_mark(2)");
-	lock_pdb_lock(r,10);
+	lock_pdb_lock(r,0);
 	sscanf(n_string(std_cm,id),"%i",&_id);
 	obj = search_obj(r,_id);
 	if ( obj == 0 ) {
@@ -233,6 +233,7 @@ param_error:
 
 int
 draw_mark(
+	GBVIEW_FLAME * gf,
 	OBJ * o,
 	DRAW_WORK * dw)
 {
@@ -259,7 +260,7 @@ int i;
 	map_from_resource(dw->mh,&p1,&er,1);
 	if ( er < 0 )
 		return -1;
-	data = get_ri(&w,&h,dw->wfid,o->mark.path);
+	data = get_ri(&w,&h,gf,dw->wfid,o->mark.path);
 	if ( data == 0 ) {
 		return -1;
 	}
@@ -298,6 +299,7 @@ int i;
 	rect.br.y = y + h;
 
 	wf_insert_si(
+		gf,
 		ISI_INSERT,
 		dw->wfid,
 		dw->resource->h.no,
@@ -314,13 +316,14 @@ int i;
 
 	p1.x = rect.br.x + 3;
 	p1.y = rect.br.y;
-	indicate_onmap(1,dw->wfid,dw->resource,o,p1);
+	indicate_onmap(gf,1,dw->wfid,dw->resource,o,p1);
 
 	return 0;
 }
 
 int
 get_point_mark(
+	GBVIEW_FLAME * gf,
 	RESOURCE * r,
 	OBJ * o,
 	GET_POINT_WORK * w)
@@ -352,7 +355,7 @@ int ww,hh;
 
 	if ( sw->select_obj != o )
 		return 0;
-	if ( get_ri(&w,&h,0,o->mark.path) == 0 )
+	if ( get_ri(&w,&h,0,0,o->mark.path) == 0 )
 		return 0;
 	p1 = o->mark.pt;
 	er = 1;
