@@ -55,7 +55,6 @@ typedef struct dm_time_list {
 } DM_TIME_LIST;
 
 extern RESOURCE ** res_entry_hash_table;
-extern GBVIEW_ENV env;
 extern int default_dgb_pixel;
 extern int spiral_count;
 
@@ -192,9 +191,9 @@ DM_TIME_LIST * ret;
 	for ( ret = tlist ; ret ; ret = ret->next )
 		if ( l_strcmp(ret->key,key) == 0 )
 			return ret;
-	ret = d_alloc(sizeof(*ret),346);
+	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
-	ret->key = ll_copy_str(key,236);
+	ret->key = ll_copy_str(key);
 
 	ret->next = tlist;
 	tlist = ret;
@@ -222,7 +221,7 @@ int max_dm,min_dm;
 int dm;
 int i;
 	sum = 0;
-	max_dm = env.win_width*env.win_height*50/
+	max_dm = 600*400*50/
 			default_dgb_pixel/default_dgb_pixel;
 	min_dm = 0;
 	for ( sub = 1 ; sub <= max_dm ; sub *= 4 )
@@ -426,7 +425,7 @@ L_CHAR * key;
 		r = n->r;
 		id = n->wfid;
 		key = n->h.key;
-		dm_list = d_alloc(sizeof(DRAW_MATRIX*)*DM_LIST_SIZE,1234);
+		dm_list = d_alloc(sizeof(DRAW_MATRIX*)*DM_LIST_SIZE);
 		for ( i = 0 ; i < DM_LIST_SIZE ; i ++ ) {
 			dm_list[i] = n->dm_list[i];
 			if ( dm_list[i] == 0 )
@@ -465,7 +464,7 @@ ss_printf("ERROR 2\n");
 
 		/***/
 
-		n = new_queue_node(sizeof(*n),236);
+		n = new_queue_node(sizeof(*n));
 		n->data = ld;
 		n->r = r;
 		n->wfid = id;
@@ -684,7 +683,7 @@ set_cpu_msg(2);
 		l_string(std_cm,"Get"),
 		List(query,-1),
 		0,0,0);
-	n = new_queue_node(sizeof(*n),2436);
+	n = new_queue_node(sizeof(*n));
 	n->data = ret;
 	n->r = r;
 	n->wfid = wfid;
@@ -788,7 +787,7 @@ printf("ERROR 4\n");
 
 
 
-		n2 = new_queue_node(sizeof(*n2),2436);
+		n2 = new_queue_node(sizeof(*n2));
 		n2->data = ret_query;
 		n2->r = n1->r;
 		n2->wfid = n1->wfid;
@@ -876,7 +875,7 @@ dm->r->draw_gb.pitch_list[dm->level+1].x,
 dm->r->draw_gb.level);
 */
 	lock_task(dm_lock);
-	dm_list = d_alloc(sizeof(DRAW_MATRIX)*DM_LIST_SIZE,1234);
+	dm_list = d_alloc(sizeof(DRAW_MATRIX)*DM_LIST_SIZE);
 	for ( i = 0 ; i < DM_LIST_SIZE ; i ++ )
 		dm_list[i] = 0;
 	dm->flags &= ~DMF_REQUEST;
@@ -1122,7 +1121,7 @@ new_draw_matrix(WF_ID wfid,RESOURCE * r,DRAW_MATRIX * dm,int x,int y)
 DRAW_MATRIX * dm1;
 int i,j;
 	touch_obj_mem(sizeof(*dm1));
-	dm1 = d_alloc(sizeof(*dm1),22);
+	dm1 = d_alloc(sizeof(*dm1));
 	dm1->get_handle_time = 0;
 	dm1->get_level = 0;
 	dm1->dm_point_list = 0;
