@@ -31,7 +31,6 @@
 #include	"proxy.h"
 #include	"rcache.h"
 
-extern GBVIEW_ENV env;
 extern char* http_client;
 extern int fontsize;
 extern int default_dgb_pixel;
@@ -41,7 +40,6 @@ XL_SEXP * setup_initial_query;
 void gc_gb_sexp(XL_SEXP * p);
 void loading_file(L_CHAR *, L_CHAR *,int);
 
-
 void
 gc_setup()
 {
@@ -101,33 +99,39 @@ window_size(XLISP_ENV * e,XL_SEXP * s)
 {
 XL_SEXP * width,*height;
 int i;
+GBVIEW_STATUS sts;
+	wf_init_status(&sts);
 	width = eval(e,get_el(s,1));
 	switch ( get_type(width) ) {
 	case XLT_FLOAT:
-		env.win_width = width->floating.data;
+		sts.width = width->floating.data;
 		break;
 	case XLT_INTEGER:
-		env.win_width = width->integer.data;
+		sts.width = width->integer.data;
 		break;
 	default:
-		env.win_width = 400;
+		sts.width = 400;
 	}
 	height = eval(e,get_el(s,2));
 	switch ( get_type(height) ) {
 	case XLT_FLOAT:
-		env.win_height = height->floating.data;
+		sts.height = height->floating.data;
 		break;
 	case XLT_INTEGER:
-		env.win_height = height->integer.data;
+		sts.height = height->integer.data;
 		break;
 	default:
-		env.win_height = 400;
+		sts.height = 400;
 	}
+	sts.flags = SF_WIDTH|SF_HEIGHT;
+	wf_set_status(wf_next_gf(0,GVFM_LIVE),&sts);
+/* init GBVIEW_FLAME
 	env.redraw = d_alloc(env.win_height*env.win_width);
 	for ( i = 0 ; i < env.win_height*env.win_width ; i ++ )
 		env.redraw[i] = RP_REDRAW;
 	env.redraw_plane 
 		= d_alloc(env.win_height*env.win_width*sizeof(long));
+*/
 	return 0;
 }
 
@@ -639,6 +643,10 @@ xl_write_status(XLISP_ENV * e,XL_SEXP * s)
 {
 char * file;
 STREAM * st;
+GBVIEW_STATUS sts;
+
+	wf_status(wf_next_gf(0,GVFS_ACTIVE),&sts);
+
 	file = d_alloc(100);
 	sprintf(file,"%s%s",get_preference_path(),GBVIEW_PARAM);
 	st = s_open_file(file,O_RDWR|O_CREAT|O_TRUNC);
@@ -661,7 +669,7 @@ STREAM * st;
 	s_printf(st,"\n</initial-query>\n");
 
 	s_printf(st,"<window-size>%i %i </window-size>\n",
-		env.win_width,env.win_height);
+		sts.width,sts.height);
 /*
 	s_printf(st,"<http-client>%s </http-client>\n",http_client);
 */
@@ -669,6 +677,7 @@ STREAM * st;
 	s_printf(st,"</gv-resource>\n\n");
 
 	s_close(st);
+	wf_free_status(&sts);
 
 	return 0;
 }
@@ -739,7 +748,6 @@ int i;
 
 	init_gv_goto_point(gblisp_top_env0);
 
-	init_indicate();
 	init_style();
 
 	init_gv_cpu(gblisp_top_env0);
@@ -759,7 +767,6 @@ STREAM * st;
 	init_obj_memory();
 	init_draw_gb();
 	init_luster_r64();
-	env.ov_lock = new_lock(LL_OV_LOCK);
 
 }
 
