@@ -19,10 +19,11 @@
 #include	"gbview.h"
 #include	"xlerror.h"
 #include	"xl.h"
+#include	"win_flame.h"
 
 XL_SEXP * xl_gv_flame_purge_select();
 
-extern GBVIEW_ENV env;
+
 
 
 void
@@ -35,7 +36,11 @@ init_gv_flame_purge_select(XLISP_ENV * env)
 
 XL_SEXP * xl_gv_flame_purge_select(
 	XLISP_ENV * e,
-	XL_SEXP * s)
+	XL_SEXP * s,
+	XLISP_ENV * a,
+	XL_SYM_FIELD * sf)
 {
-	return get_integer(wf_purge_select(),0);
+GBVIEW_FLAME * gf;
+	gf = get_gf_from_sf(sf);
+	return get_integer(wf_purge_select(gf),0);
 }
