@@ -452,16 +452,6 @@ typedef struct draw_matrix {
 	struct point_list *	dm_point_list;
 } DRAW_MATRIX;
 
-typedef struct info_req_queue {
-	struct info_req_queue *	next;
-	int			cmd;
-#define IRQ_ONLY_FETCH		1
-#define IRQ_INDICATE_CARD	2
-#define IRQ_INDICATE_ONMAP	3
-	int			code;
-	WF_ID			wfid;
-} INFO_REQ_QUEUE;
-
 typedef struct style_file {
 	struct style_file *	next;
 	struct style_file *	prev;
@@ -499,13 +489,15 @@ typedef struct draw_gb {
 #define DGT_PDB		2
 	short		level;
 	short		pdb_lock;
+	int		pdb_lock_task;
+	int		pdb_err_sensitive;
+	char *		pdb_lock_file;
+	int		pdb_lock_line;
+	int		pdb_lock_gc_flag;
 	int		flags;
 #define DGF_POLY	0x00000001
 #define DGF_INFO	0x00000002
 #define DGF_MARK	0x00000004
-	int		pdb_lock_task;
-	int		pdb_lock_msg;
-	int		pdb_lock_gc_flag;
 	REAL1		resolution;
 	AVT_NODE *	obj_code_tree;
 	RECT_TREE	obj_rect_tree;
@@ -514,7 +506,7 @@ typedef struct draw_gb {
 
 	GB_POINT *	pitch_list;
 	int		loop_no;
-	INFO_REQ_QUEUE * ir_queue;
+	SYS_QUEUE	ir_que;
 	INFO_SCHEME *	ischeme;
 	REAL1		onmap_indicate_size;
 	short		hit_level;
@@ -800,7 +792,8 @@ typedef int (*GBV_FUNC)();
 #define GBF_SELECT	5
 #define GBF_OLIST	6
 #define GBF_CHECK	7
-#define GBF_MAX		8
+#define GBF_EXIT_LOCK	8
+#define GBF_MAX		9
 
 extern XLISP_ENV * draw_gb_top;
 extern XLISP_ENV * map_top;
@@ -860,7 +853,6 @@ convert_resolution_reverse(
 	REAL1		reso,
 	GB_POINT	pt,
 	RESOURCE *	m);
-void assert_ls(int flags);
 GB_POINT
 map_conv_tric(REAL1 *res,MAP_PARAMETER * mp,GB_POINT p);
 REAL1
@@ -911,8 +903,10 @@ RESOURCE * get_map_between2(RESOURCE * obj,RESOURCE * crd);
 
 void call_gv_event(int rno,L_CHAR * msg);
 
-void lock_pdb_lock(RESOURCE * r,int msg);
+int xx_lock_pdb_lock(RESOURCE * r,int es,char * file,int line);
+#define lock_pdb_lock(r,es)	xx_lock_pdb_lock(r,es,__FILE__,__LINE__)
 void unlock_pdb_lock(RESOURCE * r);
+void pdb_err_sensitive(RESOURCE *,int);
 
 void setup_c_unit(COORDINATE_UNIT * up,int ses,L_CHAR * url,
 	XL_SEXP * meta,XL_SYM_FIELD * sf);
