@@ -85,7 +85,9 @@ typedef struct mp_route_t {
 #define RQT_MH_ERR		0x00002000
 
 #define RQT_ROUTE_REVERSE	0x00010000
+/*
 	int			wait_mode;
+*/
 	MP_ROUTE *		route;
 	MAP_HISTORY *		mh;
 
@@ -127,8 +129,9 @@ check_mappath(L_CHAR * org,L_CHAR * target,int);
 
 #define CRT_NOTHING		0
 #define CRT_LOADING		1
-#define CRT_LOADING_RES		2
-#define CRT_EXIST		3
+#define CRT_ROUTING_EXIST	2
+#define CRT_LOADING_RES		3
+#define CRT_EXIST		4
 #define CRT_ERROR		5
 #define CRT_MAX			6
 
