@@ -34,13 +34,15 @@ int er;
 unsigned int size;
 	ofs1 = CH_OFS2_FILE(f,ce);
 	size = u_lseek64(f->fd,0,SEEK_END);
+/*
+printf("W over %i %i - %i %i\n",ce->w_ofs,ce->h_ofs,ofs1,size);
+*/
 	if ( ofs1 > size )
 		_fill_background(f,ofs1-size);
 	ofs2 = u_lseek64(f->fd,ofs1,SEEK_SET);
-/*
-if ( ofs1 > 0x7fffffff )
-printf("W over %x %x %x\n",ofs1,size,ofs2);
-*/
+
+
+
 	if ( ofs2 == 0xffffffff ) {
 		r64_error = E_SYS;
 		return -1;
