@@ -88,6 +88,7 @@ void
 init_stream()
 {
 void zonbie_tick();
+void s_write_tick();
 
 	stream_lock = new_lock(LL_STREAM);
 	if ( std_cm == 0 ) {
@@ -114,4 +115,5 @@ void zonbie_tick();
 	create_task(thput_task,0,PRI_FETCH_STRONG);
 
 	new_tick(zonbie_tick,11,0);
+	new_tick(s_write_tick,2,0);
 }
