@@ -207,7 +207,7 @@ set_lock_function(L_CHAR * func)
 	if ( lock_function )
 		d_f_ree(lock_function);
 	if ( func )
-		lock_function = ll_copy_str(func,1497);
+		lock_function = ll_copy_str(func);
 	else	lock_function = 0;
 }
 
@@ -474,14 +474,14 @@ new_permission_list(XL_INTERPRETER * xli,XL_SEXP * mode)
 PERMISSION_LIST * pl;
 P_MODE * pm;
 XL_SEXP * r;
-	pl = d_alloc(sizeof(*pl),168);
+	pl = d_alloc(sizeof(*pl));
 	pl->mode = 0;
 	for ( ; get_type(mode) ; mode = cdr(mode) ) {
-		pm = d_alloc(sizeof(*pm),169);
+		pm = d_alloc(sizeof(*pm));
 		pm->next = pl->mode;
 		pl->mode = pm;
 		r = car(mode);
-		pm->name = ll_copy_str(r->string.data,1496);
+		pm->name = ll_copy_str(r->string.data);
 	}
 	init_access_permission(&pl->ap);
 	pl->next = 0;
@@ -533,7 +533,7 @@ _new_xli_thread(XL_INTERPRETER * xli)
 unsigned int key,tid;
 XL_THREAD * t;
 	lock_task(xli_lock);
-	t = d_alloc(sizeof(*t),170);
+	t = d_alloc(sizeof(*t));
 	t->xli = xli;
 	tid = t->tid = get_tid();
 	key = tid%THREAD_HASH_SIZE;
@@ -792,7 +792,7 @@ new_xl_interpreter()
 {
 XL_INTERPRETER * ret;
 int i;
-	ret = d_alloc(sizeof(*ret),171);
+	ret = d_alloc(sizeof(*ret));
 	for ( i = 0 ; i < sizeof(*ret) ; i ++ )
 		((char*)ret)[i] = 0;
 
@@ -968,7 +968,7 @@ DELAY_QUE_T  * d;
 	lock_task(xli_lock);
 	xli->delay_que_cnt ++;
 	unlock_task(xli_lock,"insert_delay_que");
-	d = new_queue_node(sizeof(*d),346);
+	d = new_queue_node(sizeof(*d));
 	d->ret = s;
 	d->line = line;
 	d->xli = xli;
