@@ -242,9 +242,9 @@ CON_PREFIX * pf;
 	pf = _search_con_prefix(a,pref,cmd);
 	if ( pf )
 		return pf;
-	pf = d_alloc(sizeof(*pf),356);
-	pf->name = ll_copy_str(pref,1591);
-	pf->cmd = ll_copy_str(cmd,1591);
+	pf = d_alloc(sizeof(*pf));
+	pf->name = ll_copy_str(pref);
+	pf->cmd = ll_copy_str(cmd);
 
 	pf->next = a->prefix;
 	a->prefix = pf;
@@ -279,7 +279,7 @@ void
 _insert_con_agent_initial(CON_AGENT * a,int ses)
 {
 CON_AGENT_INITIAL * ai;
-	ai = d_alloc(sizeof(*ai),33);
+	ai = d_alloc(sizeof(*ai));
 	ai->ses = ses;
 	ai->next = a->initial_list;
 	a->initial_list = ai;
@@ -433,9 +433,9 @@ CON_IND_AGENT * ia;
 	a = _search_con_agent(server,name);
 	if ( a )
 		return a;
-	a = d_alloc(sizeof(*a),690);
+	a = d_alloc(sizeof(*a));
 	a->lock = 0;
-	a->name = ll_copy_str(name,1593);
+	a->name = ll_copy_str(name);
 	a->iid = iid;
 	a->server = server;
 	a->prefix = 0;
@@ -490,7 +490,7 @@ CON_SERVER * s;
 	s = _search_con_server(u,ses);
 	if ( s )
 		return s;
-	s = d_alloc(sizeof(*s),688);
+	s = d_alloc(sizeof(*s));
 	copy_url(&s->url,u);
 	s->iid = 0;
 	s->agent = 0;
@@ -541,7 +541,7 @@ CON_SESSION * s;
 			break;
 		session_id ++;
 	}
-	s = d_alloc(sizeof(*s),687);
+	s = d_alloc(sizeof(*s));
 	s->access_cnt = 0;
 	s->flags = 0;
 	s->id = session_id;
@@ -779,7 +779,7 @@ INIT_SEXP_WORK * w;
 	if ( ses == 0 )
 		return -1;
 	if ( s ) {
-		w = d_alloc(sizeof(*w),22);
+		w = d_alloc(sizeof(*w));
 		w->env = env;
 		w->query = s;
 		_set_pre_func(
@@ -829,7 +829,7 @@ retry:
 	xli->env = env;
 	xli->port = u->port;
 	xli->environment = 1;
-	xli->hostname = ll_copy_str(u->server,1594);
+	xli->hostname = ll_copy_str(u->server);
 	xli->connection_timeout = ATT_INITIAL;
 
 
@@ -1181,13 +1181,13 @@ L_CHAR * agent,* login_mode, * center_cmd;
 XL_SEXP * pre_data;
 
 	if ( a_agent )
-		agent = ll_copy_str(a_agent,123);
+		agent = ll_copy_str(a_agent);
 	else	agent = 0;
 	if ( a_login_mode )
-		login_mode = ll_copy_str(a_login_mode,1354);
+		login_mode = ll_copy_str(a_login_mode);
 	else	login_mode = 0;
 	if ( a_center_cmd )
-		center_cmd = ll_copy_str(a_center_cmd,32);
+		center_cmd = ll_copy_str(a_center_cmd);
 	else	center_cmd = 0;
 
 	lock_task(session_lock);
@@ -1225,14 +1225,14 @@ XL_SEXP * pre_data;
 	if ( login_mode ) {
 		if ( ses->login_mode )
 			d_f_ree(ses->login_mode);
-		ses->login_mode = ll_copy_str(login_mode,1587);
+		ses->login_mode = ll_copy_str(login_mode);
 	}
 	if ( ses->server ) {
 		sv = ses->server;
 		if ( u->proto == 0 )
-			u->proto = ll_copy_str(sv->url.proto,1588);
+			u->proto = ll_copy_str(sv->url.proto);
 		if ( u->server == 0 )
-			u->server = ll_copy_str(sv->url.server,1589);
+			u->server = ll_copy_str(sv->url.server);
 		if ( u->port == 0 )
 			u->port = sv->url.port;
 	}
@@ -1266,7 +1266,7 @@ XL_SEXP * pre_data;
 		}
 		if ( ses->working_path )
 			d_f_ree(ses->working_path);
-		ses->working_path = ll_copy_str(u->db,1590);
+		ses->working_path = ll_copy_str(u->db);
 	}
 	else if ( u->server || u->db || u->resource ) {
 		path = compose_path(ses->working_path,u->db);
@@ -1556,13 +1556,13 @@ XL_SEXP * send_query, * ret;
 char buf[20];
 L_CHAR * a_agent,* a_login_mode,* a_center_cmd;
 	if ( _a_agent )
-		a_agent = ll_copy_str(_a_agent,22);
+		a_agent = ll_copy_str(_a_agent);
 	else	a_agent = 0;
 	if ( _a_login_mode )
-		a_login_mode = ll_copy_str(_a_login_mode,22);
+		a_login_mode = ll_copy_str(_a_login_mode);
 	else	a_login_mode = 0;
 	if ( _a_center_cmd )
-		a_center_cmd = ll_copy_str(_a_center_cmd,21);
+		a_center_cmd = ll_copy_str(_a_center_cmd);
 	else	a_center_cmd = 0;
 	if ( native_proxy_session == 0 ) {
 		ret = _remote_session(
@@ -1790,8 +1790,8 @@ NPROXY_DIRECT_SERVER * d;
 	d = _search_direct_server(server);
 	if ( d )
 		return -1;
-	d = d_alloc(sizeof(*d),22);
-	d->server = ll_copy_str(server,22);
+	d = d_alloc(sizeof(*d));
+	d->server = ll_copy_str(server);
 	d->next = np_server_list;
 	np_server_list = d;
 	return 0;
