@@ -26,6 +26,11 @@
 #include	"utils.h"
 
 
+#define LIFETIME		(3*24*3600+3)
+#define LIMIT_TOLL		(12*3600)
+
+int lock_sync();
+
 int
 _main(int argc,char ** argv)
 {
@@ -36,6 +41,11 @@ int id;
 	init_xl(INI_DONTWAITCHI);
 	init_xl_lock();
 
+	timeout_exit(
+		LIFETIME,
+		LIFETIME + LIMIT_TOLL,
+		lock_sync);
+
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_lock_function(gblisp_top_env0,gblisp_top_env1);
 	init_gv_cpu(gblisp_top_env0);
